# -*- coding: utf-8 -*-
"""
jf-ext.CurrencyExt.py
~~~~~~~~~~~~~~~~~~~~

:copyright: (c) 2018-2022 by the Ji Fu, see AUTHORS for more details.
:license: MIT, see LICENSE for more details.
"""


def currency_display_by_int(number):
    """
    >>> money: 金额 书面化 (千位 ,)
    :param {Int} number: 金额
    :return {String}: 金额书面化字符串
    """
    tmp = format(number, ',')
    return tmp



# -*- coding: utf-8 -*-
"""
jf-ext.SingletonExt.py
~~~~~~~~~~~~~~~~~~~~~~

:copyright: (c) 2018-2022 by the Ji Fu, see AUTHORS for more details.
:license: MIT, see LICENSE for more details.
"""


def Singleton(cls):
    """
    >>> 单例模块 装饰器
    """
    instances = {}

    def _singleton(*args, **kwargs):
        if cls not in instances:
            instances[cls] = cls(*args, **kwargs)
        return instances[cls]

    return _singleton



# -*- coding: utf-8 -*-
# flake8: noqa : F401
"""
jf-ext.__init__.py
~~~~~~~~~~~~~~~~~~

:copyright: (c) 2018-2022 by the Ji Fu, see AUTHORS for more details.
:license: MIT, see LICENSE for more details.
"""

# pragma mark - BasicType
# --------------------------------------------------------------------------------
from .BasicType.DictExt import *
from .BasicType.FloatExt import *
from .BasicType.JsonExt import *
from .BasicType.ListExt import *
from .BasicType.StringExt import *

# pragma mark - Time
# --------------------------------------------------------------------------------
from .Time.DateExt import *
from .Time.TimeExt import *

# pragma mark - Mgr
# --------------------------------------------------------------------------------
from .Mgr.mailMgr import MailMgr
from .Mgr.redisMgr import RedisMgr
from .Mgr.responseMgr import APIResponse, APIResponseType


from .CommonExt import *
from .CurencyExt import *
from .EncryptExt import *
from .IpExt import *
from .PrintExt import *
from .RequestExt import *
from .SingletonExt import *
from .ValidExt import *
from .fileExt import *



# -*- coding: utf-8 -*-
"""
jf-ext.BasicType.DictExt.py
~~~~~~~~~~~~~~~~~~~~~~~~~~~

:copyright: (c) 2018-2022 by the Ji Fu, see AUTHORS for more details.
:license: MIT, see LICENSE for more details.
"""


def dict_get_and_insert(dic, key, default):
    """
    >>> 字典: 获取字段, 未找到直接插入
    :param {dictionary} dic: 待处理字典
    :param {String} key: 键
    :param {Any} default: 默认插入值
    """
    if not dic.get(key, None):
        dic[key] = default
    return


def dict_flatten(obj):
    """
    >>> 字典拍平
    """
    from jfExt.BasicType.ListExt import list_to_string
    if not isinstance(obj, dict):
        return False
    new_obj = dict()
    for i in obj.keys():
        # 字典类型展开
        if isinstance(obj[i], dict):
            for j in obj[i].keys():
                tmp = list_to_string(obj[i][j])
                new_obj["{}_{}".format(i, j)] = tmp
            continue
        if isinstance(obj[i], list):
            new_obj[i] = list_to_string(obj[i])
            continue
        new_obj[i] = obj[i]
    return new_obj



# -*- coding: utf-8 -*-
"""
jf-ext.Mgr.responseMgr.py
~~~~~~~~~~~~~~~~~~~~~~~~~

:copyright: (c) 2018-2022 by the Ji Fu, see AUTHORS for more details.
:license: MIT, see LICENSE for more details.
"""

import json
from flask import jsonify
from ..EncryptExt import *
from ..Time.TimeExt import *


class APIResponseType():
    """
    >>> API 业务响应类型
    """

    # 成功
    SUCCESS = 0
    # 错误
    # - 1xx
    ERROR_INTERNAL = 100                    # 内部错误
    ERROR_REQUEST_URL_FORMAT = 101          # URL未找到
    ERROR_REQUEST_PARAM_FORMAT = 102        # GET请求 参数错误
    ERROR_REQUEST_DATA_FORMAT = 103         # POST请求 JSON参数错误
    ERROR_REQUEST_DATA_MD5 = 104            # POST请求 MD5验证失败
    ERROR_VERIFICATION = 105                # 错误验证码
    ERROR_USER_EXIST = 106                  # 用户已存在
    ERROR_USER_NOT_EXIST = 107              # 用户不存在
    ERROR_USER_WRONG_PASSWD = 108           # 用户密码错误
    ERROR_NO_RESULT = 110                   # 无查询数据
    ERROR_AUTH_FAILURE = 120                # 授权失败
    ERROR_TOO_FAST = 130                    # 请求过快
    ERROR_UNDEFINED = 140                   # 未定义
    ERROR_DATA_EXIST = 150                  # 数据已存在
    ERROR_DATA_NOT_EXIST = 151              # 数据不存在存在
    ERROR_SEARCH_KEYWORD_TOO_SHORT = 160    # 搜索关键词太短
    # - 4xx
    ERROR_ERROR_TOKEN = 402                 # token 错误
    ERROR_NO_PERMISSION = 403               # 权限不足
    # - 6xx
    ERROR_SERVER_MAINTENANCE = 600          # 服务器维护
    # 业务代码 9XXX
    ERROR_BUSINESS_DOMAIN_NOT_FOUND = 9001      # 域名未找到
    ERROR_BUSINESS_STANDARD_SKU_EXIST = 9010    # 规格barcode已存在
    # - 9999
    ERROR_SILENT = 9999                     # 错误静音


class APIResponse():

    @classmethod
    def error(cls, code, msg=None):
        """
        >>> 响应: error
        :param {Int} code: 业务错误状态码
        :param {String} msg: 业务错误描述
        :return {JSON}: 响应body
        """
        if code > 0:
            for key in APIResponseType.__dict__:
                standard_code = getattr(APIResponseType, key, -1)
                if standard_code == code and not msg:
                    msg = key
            print("%" * 50)
            print("error [{}] - {}".format(code, msg))
            data_json = json.dumps(
                {},
                separators=(',', ':'),
                ensure_ascii=False,
                sort_keys=True
            )
            return jsonify({
                'code': code,
                'msg': msg,
                'data': {},
                'md5': generate_md5(data_json),
            })

    @classmethod
    def success(cls, data):
        """
        >>> 响应: success
        :param {String} data: 响应数据
        :return {JSON}: 响应body
        """
        data_json = json.dumps(
            data,
            separators=(',', ':'),
            ensure_ascii=False,
            sort_keys=True
        )
        return jsonify({
            'code': APIResponseType.SUCCESS,
            'msg': "SUCCESS",
            'data': data,
            'md5': generate_md5(data_json),
            'timestamp': time_now_timestamp()
        })



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages


def update_current_version():
    # try:
    #     fp = open('version', 'r')
    #     [major, sub, rev] = fp.read().split('.')
    #     version = '{}.{}.{}'.format(major, sub, str(int(rev) + 1))
    #     fp.close()
    #     fp = open('version', 'w')
    #     fp.write(version)
    #     return version
    # except Exception:
    #     return "1.0.0"
    return "1.2.2"


setup(
    name='jfExt',
    version=update_current_version(),
    description='private common python framework',
    long_description='...',
    keywords='jfExt',
    author='jifu',
    author_email='ji.fu@icloud.com',
    url='http://www.jifu.io',
    license='MIT',
    packages=find_packages(exclude=["test", '*.pyc']),
    install_requires=[
        'flask', 'flask_mail', 'flask_redis',
        'six', 'prettytable', 'requests',
        'uuid', 'validators', 'geoip2',
        'icecream', 'urllib3'
    ],
    extras_require={
    },
    package_data={},
    include_package_data=True,
    zip_safe=True,
)
